<?php
    if ( ! class_exists( 'ArnicaPluginConfig' ) ) {
        class ArnicaPluginConfig {

            public $args = array();
            public $sections = array();
            public $theme;
            public $ReduxFramework;

            public function __construct() {
                if ( ! class_exists( 'ReduxFramework' ) ) {
                    return;
                }
				
				add_action( 'plugins_loaded', array( $this, 'initSettings' ), 10 );
            }

            public function initSettings() {
                $this->theme = wp_get_theme();
				$this->setArguments();
                $this->setSections();
				
                if ( ! isset( $this->args[ 'opt_name' ] ) ) { // No errors please
                    return;
                }
				
				$this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
			}
			
            /**
             * Filter hook for filtering the default value of any given field. Very useful in development mode.
             * */
            function change_defaults( $defaults ) {
                $defaults[ 'str_replace' ] = 'Testing filter hook!';

                return $defaults;
            }

            // Remove the demo link and the notice of integrated demo from the redux-framework plugin
            function remove_demo() {

                // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
                if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                    remove_filter( 'plugin_row_meta', array(
                        ReduxFrameworkPlugin::instance(),
                        'plugin_metalinks'
                    ), null, 2 );

                    // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                    remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
                }
            }
			
			public function allowAccess() {
				global $arnicaConfig;
				$allow = false;
				
				// IP Address
				$ip = $_SERVER[ 'REMOTE_ADDR' ];
				$ip_address = $arnicaConfig[ 'ip_address' ];
				
				if( isset( $ip_address ) && !empty( $ip_address ) ) {
					$arr_ip_address = explode( "\r\n", $ip_address );
					
					if( in_array( $ip, $arr_ip_address ) ) {
						$allow = true;
					} else {
						$allow = false;
					}
				}
				
				// Exclude URL
				$url = ( isset( $_SERVER[ "HTTPS" ] ) ) ? "https://" : "http://";
                $url .= $_SERVER[ "SERVER_NAME" ] . $_SERVER[ "REQUEST_URI" ];
				
				$exclude_url = $arnicaConfig[ 'exclude_url' ];
                
                if( isset( $exclude_url ) && !empty( $exclude_url ) ) {
					$arr_exclude_url = explode("\r\n", $exclude_url);					
				
					foreach( $arr_exclude_url as $page ) {
						if ( preg_match( "#".$page."#", $url ) && ( strlen( $page ) == strlen( $url ) ) ) {
							$allow = true;
						}
		
						$page_new = preg_replace( "/\?/", "", $page );
						$url_new = preg_replace( "/\?/", "", $url );                  
                        
						if ( preg_match( "#" . $page_new . "#", $url_new ) && ( strlen( $page_new ) == strlen( $url_new ) ) ) {
							$allow = true;
						}
					}
				}
		
				// Result
				return $allow;
			}

			public function setSections() {
				require_once( 'sections/main.php' );
				require_once( 'sections/background.php' );
				require_once( 'sections/countdown.php' );
				require_once( 'sections/subscribe.php' );
				require_once( 'sections/about.php' );
				require_once( 'sections/contact_info.php' );
                require_once( 'sections/contact_form.php' );
				require_once( 'sections/map.php' );
				require_once( 'sections/footer.php' );
				require_once( 'sections/allow.php' );
				require_once( 'sections/seo.php' );
				require_once( 'sections/custom_css_js.php' );
				require_once( 'sections/export.php' );
			}

            public function setArguments() {
				$this->theme  = wp_get_theme();

                $this->args = array(
                    // TYPICAL -> Change these values as you need/desire
                    'opt_name'             => 'arnicaConfig',
                    'display_name'         => esc_html__( 'Arnica', 'arnica' ),
                    'display_version'      => '1.9',
                    'menu_type'            => 'menu',
                    'allow_sub_menu'       => true,
                    'menu_title'           => esc_html__( 'Arnica', 'arnica' ),
                    'page_title'           => esc_html__( 'Arnica Plugin Options', 'arnica' ),
                    'footer_credit'        => '',
                    'async_typography'     => true,
                    'admin_bar'            => true,
                    'admin_bar_icon'       => 'dashicons-portfolio',
                    'admin_bar_priority'   => 50,
					
					'global_variable'      => '',
                    // Set a different name for your global variable other than the opt_name
					
                    'dev_mode'             => false, //disable.
                    'update_notice'        => false,
                    'customizer'           => true,
                    'page_priority'        => 103,
                    'page_permissions'     => 'manage_options',
                    'menu_icon'            => 'dashicons-art',
                    'last_tab'             => '', 
                    'page_icon'            => 'icon-themes',
                    'page_slug'            => 'arnica_options',
                    'save_defaults'        => true,
                    'default_show'         => false,
                    'default_mark'         => '',
                    'show_import_export'   => true,

                    // CAREFUL -> These options are for advanced use only
                    'transient_time'       => 60 * MINUTE_IN_SECONDS,
                    'output'               => true,
                    'database'             => '',
                    'system_info'          => false,

                    // HINTS
                    'hints'                => array(
                        'icon'          => 'icon-question-sign',
                        'icon_position' => 'right',
                        'icon_color'    => 'lightgray',
                        'icon_size'     => 'normal',
                        'tip_style'     => array(
                            'color'   => 'light',
                            'shadow'  => true,
                            'rounded' => false,
                            'style'   => '',
                        ),
                        'tip_position'     => array(
                            'my' => 'top left',
                            'at' => 'bottom right',
                        ),
                        'tip_effect'       => array(
                            'show' => array(
                                'effect'   => 'slide',
                                'duration' => '500',
                                'event'    => 'mouseover',
                            ),
                            'hide' => array(
                                'effect'   => 'slide',
                                'duration' => '500',
                                'event'    => 'click mouseleave',
                            ),
                        ),
                    )
                );
				
				//Custom links in the footer of Redux panel
				$this->args['share_icons'][] = array(
					'url'   => 'https://themeforest.net/user/athenastudio',
					'title' => esc_html__( 'AthenaStudio', 'arnica' ),
					'icon'  => 'el el-globe-alt'
				);

				$this->args['share_icons'][] = array(
					'url'   => 'https://twitter.com/AthenaStudio87',
					'title' => esc_html__( 'Twitter', 'arnica' ),
					'icon'  => 'el el-twitter'
				);

				$this->args['share_icons'][] = array(
					'url'   => 'https://dribbble.com/AthenaStudio',
					'title' => esc_html__( 'Dribbble', 'arnica' ),
					'icon'  => 'el el-dribbble'
				);
                
            }

        }

        global $arnicaPluginConfig;
        $arnicaPluginConfig = new ArnicaPluginConfig();
    } else {
        echo "Arnica Plugin has been called for twice!";
    }

	include_once('font-awesome/all_icons.php');
	include_once('font-awesome/social_icons.php');
?>