<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'ReduxFramework_social' ) ) {

    class ReduxFramework_social extends ReduxFramework {

        // Field constructor
        function __construct( $field = array(), $value = '', $parent = '' ) {
            $this->parent = $parent;
            $this->field = $field;
            $this->value = $value;

            $this->enqueue();
        }

        // Field render
        public function render() {
            echo '<div class="redux-accordion">';
            $x = 0;
			
			// Load existing values
            if ( isset( $this->value ) && is_array( $this->value ) ) {
                $socials = $this->value;

                foreach ( $socials as $social ) {
                    if ( empty( $social ) ) {
                        continue;
                    }
					
                    $defaults = array(
                        'title' 	=> '',
                        'force_row' => 0,
                        'sort' 		=> '',
                        'url' 		=> '',
                        'select' 	=> array(),
                    );
					
                    $social = wp_parse_args( $social, $defaults );
					
					if ( $social[ 'title' ] != '' ) {
						echo '<div class="redux-accordion-group">
								<fieldset class="redux-field" data-id="' . esc_attr( $this->field[ 'id' ] ) . '">
									<h3>
										<span class="redux-header">' . $social[ 'title' ] . '</span>
									</h3>

									<div>
										<ul id="' . esc_attr( $this->field[ 'id' ] ) . '-ul" class="redux-list">

											<input 
												type="hidden" 
												id="' . esc_attr( $this->field[ 'id' ] ) . '-sort_' . esc_attr( $x ) . '" 
												name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][sort]" 
												value="' . esc_attr( $social[ 'sort' ] ) . '"
												class="social-sort" 
											/>

											<li>
												<label>' . esc_html__( 'Title', 'arnica' ) . '</label>
												<input
													type="text" 
													id="' . esc_attr( $this->field[ 'id' ] ) . '-title_' . esc_attr( $x ) . '" 
													name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][title]" 
													value="' . esc_attr( $social[ 'title' ] ) . '" 
													placeholder="' . esc_attr__( 'Label', 'arnica' ) . '" 
													class="regular-text social-title"
												/>
											</li>

											<li>
												<label>' . esc_html__( 'Url', 'arnica' ) . '</label> 
												<input 
													type="text" 
													id="' . esc_attr( $this->field[ 'id' ] ) . '-url_' . esc_attr( $x ) . '" 
													name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][url]" 
													value="' . esc_attr( $social[ 'url' ] ) . '" 
													placeholder="' . esc_attr__( 'Link', 'arnica' ) . '" 
													class="regular-text"
												/>
											</li>';

											if ( isset( $this->field[ 'options' ] ) && !empty( $this->field[ 'options' ] ) ) {
												// If there are any let's pass them to js
												if ( isset( $this->field[ 'select2' ] ) ) {
													$select2_params = json_encode( esc_attr( $this->field[ 'select2' ] ) );
													$select2_params = htmlspecialchars( $select2_params , ENT_QUOTES );

													echo '<input 
															type="hidden" 
															class="select2_params" 
															value="'. esc_attr( $select2_params ) .'"
														  >';
												}

												echo '<li>
														<label>' . esc_html__( 'Icon', 'arnica' ) . '</label>
														<select 
															id="' . esc_attr( $this->field[ 'id' ] ) . '-select" 
															data-placeholder="' . ( isset( $this->field[ 'placeholder' ][ 'options' ] ) ? esc_attr( $this->field[ 'placeholder' ][ 'options' ] ) : esc_attr__( 'Select an Icon', 'arnica' ) ) . '" 
															name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][select]" 
															class="font-awesome-icons redux-select-item ' . esc_attr( $this->field[ 'class' ] ) . '" 
															rows="6"
														  >
															<option value="">' . esc_html__( 'Select an Icon', 'arnica' ) . '</option>
													  ';

													foreach( $this->field[ 'options' ] as $k => $v ) {
														if ( is_array( $this->value ) ) {
															$selected = $social[ 'select' ] == $k ? ' selected="selected"' : '';
														} else {
															$selected = selected( $this->value[ 'select' ], $k, false );
														}

														echo '<option value="' . esc_attr( $k ) . '"' . $selected . '>' . esc_attr( $v ) . '</option>';
													}

												echo '	</select>
													  </li>';
											}

						echo '				<li>
												<a href="javascript:void(0);" class="button deletion redux-remove">
													' . esc_html__( 'Delete Link', 'arnica' ) . '
												</a>
											</li>
										</ul>
									</div>
								</fieldset>
							  </div>';

						$x++;
					}
                }
            }

			// Add new value
            if ($x == 0) {
                echo '<div class="redux-accordion-group hidden">
						<fieldset class="redux-field" data-id="' . esc_attr( $this->field[ 'id' ] ) . '">
							<h3>
								<span class="redux-header">' . esc_html__( 'New Social', 'arnica' ) . '</span>
							</h3>
							
							<div>
								<ul id="' . esc_attr( $this->field[ 'id' ] ) . '-ul" class="redux-list">
									
									<input
										type="hidden" 
										id="' . esc_attr( $this->field[ 'id' ] ) . '-sort_' . esc_attr( $x ) . '"
										name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][sort]" 
										value="' . esc_attr( $x ) . '"
										class="social-sort"
									/>
										
									<li>
										<label>' . esc_html__( 'Title', 'arnica' ) . '</label>
										<input 
											type="text" 
											id="' . esc_attr( $this->field[ 'id' ] ) . '-title_' . esc_attr( $x ) . '" 
											name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][title]" 
											value="" 
											placeholder="' . ( isset( $this->field[ 'placeholder' ][ 'title' ] ) ? esc_attr( $this->field[ 'placeholder' ][ 'title' ] ) : esc_attr__( 'Label', 'arnica' ) ) . '" 
											class="regular-text social-title" 
										/>
									</li>
									
									<li>
										<label>' . esc_html__( 'Url', 'arnica' ) . '</label>
										<input 
											type="text" 
											id="' . esc_attr( $this->field[ 'id' ] ) . '-url_' . esc_attr( $x ) . '" 
											name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][url]" 
											value="" 
											placeholder="' . ( isset( $this->field[ 'placeholder' ][ 'url' ] ) ? esc_attr( $this->field[ 'placeholder' ][ 'url' ] ) : esc_attr__( 'Link', 'arnica' ) ) . '" 
											class="regular-text" 
										/>
									</li>';
                    
									if ( isset( $this->field['options'] ) && !empty( $this->field[ 'options' ] ) ) {
											// If there are any let's pass them to js
											if ( isset( $this->field['select2'] ) ) {
												$select2_params = json_encode( esc_attr( $this->field['select2'] ) );
												$select2_params = htmlspecialchars( $select2_params , ENT_QUOTES);

												echo '<input 
														type="hidden" 
														class="select2_params" 
														value="'. esc_attr( $select2_params ) .'"
													  >';							
											}					

											echo '<li>
													<label>' . esc_html__( 'Icon', 'arnica' ) . '</label>
													<select
														id="' . esc_attr( $this->field[ 'id' ] ) . '-select" 
														data-placeholder="' . ( isset( $this->field[ 'placeholder' ][ 'select' ] ) ? esc_attr( $this->field[ 'placeholder' ][ 'select' ] ) : esc_attr__( 'Select an Icon', 'arnica' ) ) . '" 
														name="' . esc_attr( $this->field[ 'name' ] ) . '[' . esc_attr( $x ) . '][select]" 
														class="font-awesome-icons redux-select-item ' . esc_attr( $this->field[ 'class' ] ) . '" 
														rows="6"
													  >
														<option value="" selected>' . esc_html__( 'Select an Icon', 'arnica' ) . '</option>';

												foreach( $this->field[ 'options' ] as $k => $v ) {
													echo '<option value="' . esc_attr( $k ) . '">' . esc_attr( $v ) . '</option>';
												}

											echo '	</select>
												  </li>';
										}
				
				echo '					<li>
											<a href="javascript:void(0);" class="button deletion redux-remove">
												' . esc_html__( 'Delete Link', 'arnica' ) . '
											</a>
						  				</li>
									</ul>
								</div>
							</fieldset>
						  </div>';
            }
			
            echo '</div>
				  <a href="javascript:void(0);" class="button redux-add button-primary" 
				  	rel-id="' . esc_attr( $this->field[ 'id' ] ) . '-ul" rel-name="' . esc_attr( $this->field[ 'name' ] ) . '[title][]">
					' . esc_attr__('Add Link', 'arnica' ) . '
				  </a>
				  <br/>';
		}

        // Enqueue scripts & styles
        public function enqueue() {
            wp_enqueue_script(
                'redux-field-js',
                plugins_url( 'social.js' , __FILE__ ),
                array( 'jquery', 'jquery-ui-core', 'jquery-ui-accordion', 'wp-color-picker', 'select2-js' ),
                time(),
                true
            );
			
            wp_enqueue_style(
                'redux-field-css',
                plugins_url( 'social.css' , __FILE__ ),
                time(),
                true
            );
        }
    }
}
